# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# $Id: esg_config.py,v 1.2 2006/12/01 15:38:47 roeder Exp $

__author__  = 'Maik Roeder <maik.roeder@ingeniweb.com>'
__docformat__ = 'restructuredtext'

from Products.funittest import physical
from Products.funittest import dataprovider
from Products.funittest import logical
from Products.funittest import register_esg

class Config:
      
    ignored_keys = ['last_execution_date',
                    'id',
                    'taskId',
                    ]

    def ignore_keys(self, snapshot):
        copied = snapshot.copy()
        for key in self.ignored_keys:
            try:
                del copied[key]
            except:
                pass                    
        return copied
        
    def snapshot(self, state):
        sites={}
        for site in logical.config.getExternalSitesInfo():
            sites[site['title']] = self.ignore_keys(site)
        state.set('externalsites', sites)

    def on_remove_all_externalsites(self, state):
        state.set('externalsites', {}) # We expect all sites to be removed
    
    def remove_all_externalsites(self):
        self.interpreter.annotate("Check the status message")
        physical.configlet.verify_changes_made()

    def on_add_externalsite(self, site, state):
        sites={}
        for existing_site in logical.config.getExternalSitesInfo():
            sites[existing_site['title']]=self.ignore_keys(existing_site)
        sites[site['title']]=self.ignore_keys(site)
        state.set('externalsites', sites) 
        
    def add_externalsite(self, site):
        self.interpreter.annotate("Check that Site '%s' appears in configlet" %site['title'] )
        if not physical.externalsites.is_contained(site):
            raise "Need to be able to fail here"

    def on_reconfigure_externalsite(self, site1, site2, state):
        sites={}
        for external_site in logical.config.getExternalSitesInfo()():
            sites[external_site['title']]=external_site
        del sites[site1['title']]
        sites[site2['title']]=self.ignore_keys(site2)
        state.set('externalsites', sites) 
            
    def reconfigure_externalsite(self, site1, site2):
        self.interpreter.annotate("Make sure that Site '%s' appears in configlet instead of site '%s'" %(site2['title'],site1['title']))
        if physical.externalsites.is_contained(site1):
            raise "Site not expected to configured"
        if not physical.externalsites.is_contained(site2):
            raise "Site expected to be configured!"
        
    def access_config(self):
        pass
		
    def select_externalsite(self, site):
        pass

    def edit_externalsite(self, site):
        self.interpreter.annotate("Check the status message")
        physical.configlet.verify_changes_made(site)
        
    def index_externalsite(self, site):
        pass

register_esg("ExternalSiteCatalog", Config())
    