﻿# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# $Id: test_configlet.py,v 1.5 2006/12/04 15:25:26 roeder Exp $

__author__  = 'Maik Roeder <maik.roeder@ingeniweb.com>'
__docformat__ = 'restructuredtext'

import unittest
from Products.funittest import logical
from Products.funittest import physical
from Products.funittest import dataprovider
from Products.funittest import precondition
from Products.funittest import TestCase

import os

class TestConfiglet(TestCase):
    "The the configlet of the External Site Catalog product"

    def setUp(self):    
        TestCase.setUp(self)
        self.interpreter.open("")        
        user={'id':'sampleadmin'}        
        logical.application.change_user(user)
        precondition.config.no_existing_configurations()    
        
    def test_01_daily_refresh_is_scheduled(self):
        "Add a site that is refreshed daily, and is currently scheduled"
        dailysite = dataprovider.externalsite.take('Daily, scheduled for now')
        logical.config.add_externalsite(dailysite)
        self.failUnless(physical.configlet.containsSite(dailysite))
        #self.failUnless(logical.config.is_pending(dailysite))
        
    def test_02_monthly_refresh_is_scheduled(self):
        " Add a site that is refreshed monthly, and is currently scheduled"
        monthlysite = dataprovider.externalsite.take('Monthly, scheduled for now')
        logical.config.add_externalsite(monthlysite)
        self.failUnless(physical.configlet.containsSite(monthlysite))
        #self.failUnless(logical.config.is_pending(monthlysite))

    def test_03_add_many_externalsites(self):
        "Add a bunch of external sites to the configuration"
        for site in dataprovider.externalsite.all():
            logical.config.access_externalsitecatalog_configlet()
            logical.config.add_externalsite(site)
        logical.config.access_externalsitecatalog_configlet()
        for site in dataprovider.externalsite.all():
            if site['title']=='Password but no login':
                self.failIf(physical.configlet.containsSite(site))
            elif site['title']=='Login but no password':
                self.failIf(physical.configlet.containsSite(site))            
            else:
                #os.system("pause")
                self.failUnless(physical.configlet.containsSite(site))
        
    def test_04_add_externalsite_and_edit_it_again(self):
        "Add a site, and edit it again"
        site1 = dataprovider.externalsite.take('Site 1')
        site2 = dataprovider.externalsite.take('Site 2')
        logical.config.add_externalsite(site1)
        self.failUnless(physical.configlet.containsSite(site1))
        logical.config.reconfigure_externalsite(site1, site2)
        self.failUnless(physical.configlet.containsSite(site2))
        self.failIf(physical.configlet.containsSite(site1))

if __name__ == "__main__":
    unittest.main()
