# -*- coding: utf-8 -*-
## ExternalSiteCatalog
## Index and search external sites in a Plone site
## Copyright (C)2006 Ingeniweb

## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.

## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.

## You should have received a copy of the GNU General Public License
## along with this program; see the file COPYING. If not, write to the
## Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#
# Test the SearchPortlet View
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from DateTime import DateTime
from Products.CMFPlone.tests import PloneTestCase
from Products.ExternalSiteCatalog.browser.interfaces import ISearchPortlet
from Products.ExternalSiteCatalog.browser.portlets.search import SearchPortlet
from Products.ExternalSiteCatalog.tool import make_hostname

TEST_SERVER_URL = os.environ.get("TEST_SERVER_URL")

try:
    from Products.CMFCore.utils import BrowserView
    BROWSERVIEW=1
except:
    BROWSERVIEW=0
    
class TestSearchPortletView(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.url = self.portal.portal_url

    def testImplementsISearchPortlet(self):
        """SearchPortlet must implement ISearchPortlet"""
        self.failUnless(ISearchPortlet.implementedBy(SearchPortlet))

    def testHostnames(self):
        """SearchPortlet.hostnames() must return hostnames that have been indexed"""
	    # clear out the external site catalog to guarantee no hostnames
        self.portal.portal_externalcatalog.manage_catalogClear()
        request = {'taskId':None,
                   'title':"Localhost",
                   'charset':'utf-8',
                   'login':None,
                   'password':None,
                   'last_execution_date':DateTime()-10,
                   'max_duration':24,
                   'max_pages':2,
                   'scheduled_hour':1,
                   'period':'daily',
                   'url':TEST_SERVER_URL,
                   'path_incl_regexps':(),
                   'path_excl_regexps':()
                   }
        self.portal.portal_externalcatalog.addExternalSiteCatalogTask(request)
        self.portal.portal_externalcatalog.indexExternalSiteCatalogTasks(ids=['externalsitecatalogtask'])
        view = SearchPortlet(self.portal, self.app.REQUEST)
        hostnames = view.hostnames()
        self.failUnless(len(hostnames)==1, str(hostnames))
        self.failUnlessEqual(hostnames[0], make_hostname(TEST_SERVER_URL), hostnames[0] + "!=" +make_hostname(TEST_SERVER_URL))

    def testNoHostnames(self):
        """SearchPortlet.hostnames() must return an empty list when no indexed external sites"""
	    # clear out the external site catalog to guarantee no hostnames
        self.portal.portal_externalcatalog.manage_catalogClear()
        view = SearchPortlet(self.portal, self.app.REQUEST)
        hostnames = view.hostnames()
        self.failUnless(len(hostnames)==0, str(hostnames))

def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    if BROWSERVIEW:
        suite.addTest(makeSuite(TestSearchPortletView))
    return suite

if __name__ == '__main__':
    framework()
